package com.oracle.wci.ucm;

/**
 * Constants for the crawler, mostly names used in the named value pairs of the crawler and data source editors.
 * @author <a href="mailto:clinton.davidson@oracle.com">Clinton Davidson</a>
 * @version $Revision: #4 $ ($Change: 348620 $)
 */
public final class CrawlConstants {
	/**
	 * Constants for values stored in the datasource or crawler editors, and
	 * read during the crawl.
	 */
	public static final class Provider {
		/**
		 * Private constructor.
		 */
		private Provider() {
			// no-op
		}

		/**
		 * Username used to connect to ucm, set in the data source page.
		 */
		public static final String USERNAME = "USERNAME";
		/**
		 * Ucm servername, set in the data source page.
		 */
		public static final String UCM_SERVER = "UCMSERVER";
		/**
		 * Ucm port number, set in the data source page.
		 */
		public static final String UCM_PORT = "UCMPORT";
		/**
		 * Idc url, made by concatenating "idc://" with the UCM_SERVER, ":", and
		 * UCM_PORT.
		 */
		public static final String IDC_URL = "IDCURL";
		/**
		 * Root crawl folder name and id in tree page.
		 */
		public static final String ROOT_FOLDER_NAME_AND_ID = "ROOTFOLDERNAMEANDID";
		/**
		 * Root crawl folder id in tree page.
		 */
		public static final String ROOT_FOLDER_ID = "ROOTFOLDERID";
		/**
		 * Start folder name in crawl.
		 */
		public static final String START_FOLDER_NAME = "STARTFOLDERNAME";
		/**
		 * Start folder id in crawl.
		 */
		public static final String START_FOLDER_ID = "STARTFOLDERID";
		/**
		 * Repost form name in tree page.
		 */
		public static final String REPOST = "REPOST";
		/**
		 * Crawl root form name in tree page.
		 */
		public static final String CRAWL_ROOT = "CRAWLROOT";
	}

	/**
	 * Grab bag of other constants.
	 */
	public static final class Misc {
		/**
		 * Private constructor.
		 */
		private Misc() {
			// no-op
		}

		/**
		 * Utf-8 for encoding.
		 */
		public static final String UTF8 = "UTF-8";
		/**
		 * Content type for setting the correct header to the index server.
		 */
		public static final String CONTENT_TYPE = "Content-Type";
		/**
		 * Temp file name used as param in request to index server.
		 */
		public static final String TEMP_FILENAME = "TEMPFILENAME";
		/**
		 * Domain name. See if this should be part of the data source.
		 */
		public static final String DOMAIN_NAME = "UCM";
	}

}
