package com.oracle.wci.ucm;

/**
 * Constants for UCM (Stellent) method calls.
 * 
 * @author <a href="mailto:clinton.davidson@oracle.com">Clinton Davidson</a>
 * @version $Revision: #4 $ ($Change: 348620 $)
 */
public final class UcmConstants {
	/**
	 * Field names.
	 */
	public static final class Field {
		/**
		 * Private constructor.
		 */
		private Field() {
			// no-op
		}

		/**
		 * User who checked out the current revision.
		 */
		public static final String CUR_REV_CHECKOUT_USER = "CurRevCheckoutUser";
		/**
		 * Action date, which is usually used for the date the document was
		 * checked out.
		 */
		public static final String D_ACTION_DATE = "dActionDate";

		/**
		 * Folder Id.
		 */
		public static final String D_COLLECTION_ID = "dCollectionID";
		/**
		 * Folder name.
		 */
		public static final String D_COLLECTION_NAME = "dCollectionName";
		/**
		 * Document url.
		 */
		public static final String DOC_URL = "DocUrl";
		/**
		 * Folder owner.
		 */
		public static final String D_COLLECTION_OWNER = "dCollectionOwner";
		/**
		 * Folder path.
		 */
		public static final String D_COLLECTION_PATH = "dCollectionPath";

		/**
		 * Document or folder creation date.
		 */
		public static final String D_CREATE_DATE = "dCreateDate";

		/**
		 * Document or folder modified date.
		 */
		public static final String D_MODIFY_DATE = "dLastModifiedDate";
		/**
		 * Document account.
		 */
		public static final String D_DOC_ACCOUNT = "dDocAccount";

		/**
		 * Document author.
		 */
		public static final String D_DOC_AUTHOR = "dDocAuthor";
		/**
		 * Document Id.
		 */
		public static final String D_DOC_ID = "dDocID";
		/**
		 * Document name.
		 */
		public static final String D_DOC_NAME = "dDocName";

		/**
		 * Content type.
		 */
		public static final String D_DOC_FORMATS = "dDocFormats";

		/**
		 * Document title.
		 */
		public static final String D_DOC_TITLE = "dDocTitle";
		/**
		 * Document type.
		 */
		public static final String D_DOC_TYPE = "dDocType";
		/**
		 * File size in bytes.
		 */
		public static final String D_FILE_SIZE = "dFileSize";
		/**
		 * Whether a document is checked out.
		 */
		public static final String D_IS_CHECKED_OUT = "dIsCheckedOut";
		/**
		 * Checkout user.
		 */
		public static final String D_CHECKOUT_USER = "dCheckoutUser";

		/**
		 * Object id.
		 */
		public static final String D_ID = "dID";

		/**
		 * Checked in date.
		 */
		public static final String D_IN_DATE = "dInDate";

		/**
		 * Original (uploaded) file name.
		 */
		public static final String D_ORIGINAL_NAME = "dOriginalName";

		/**
		 * Parent folder id.
		 */
		public static final String D_PARENT_COLLECTION_ID = "dParentCollectionID";
		/**
		 * Document release date.
		 */
		public static final String D_RELEASE_DATE = "dReleaseDate";

		/**
		 * Document revision label.
		 */
		public static final String D_REV_LABEL = "dRevLabel";
		/**
		 * Ucm Security Group.
		 */
		public static final String D_SECURITY_GROUP = "dSecurityGroup";

		/**
		 * Whether the folder has a collection id.
		 */
		public static final String HAS_COLLECTION_ID = "hasCollectionID";

		/**
		 * Whether the folder has a collection path.
		 */
		public static final String HAS_COLLECTION_PATH = "hasCollectionPath";
		/**
		 * Whether the folder has a parent collection id.
		 */
		public static final String HAS_PARENT_COLLECTION_ID = "hasParentCollectionID";

		/**
		 * Primary file for uploading a document to stellent.
		 */
		public static final String PRIMARY_FILE = "primaryFile";

		/**
		 * How to return a file- web-primary- alternate.
		 */
		public static final String RENDITION = "Rendition";

		/**
		 * Folder id when used with documents.
		 */
		public static final String X_COLLECTION_ID = "xCollectionID";

		/**
		 * Document comments.
		 */
		public static final String X_COMMENTS = "xComments";
		/**
		 * Force folder security.
		 */
		public static final String X_FORCE_FOLDER_SECURITY = "xForceFolderSecurity";
		/**
		 * Revision id, which is usually an integer.
		 */
		public static final String D_REVISION_ID = "dRevisionID";
		/**
		 * Collection mark, used to determine the trash folder.
		 */
		public static final String D_COLLECTION_MARK = "dCollectionMark";
		/**
		 * Collection name, used as a backup to get the folder name if
		 * dCollectionName is not populated.
		 */
		public static final String COLLECTION_NAME = "collectionName";
	}

	/**
	 * Result set names.
	 */
	public static final class ResultSet {
		/**
		 * Private constructor.
		 */
		private ResultSet() {
			// no-op
		}

		/**
		 * Result set of folders.
		 */
		public static final String COLLECTIONS = "COLLECTIONS";

		/**
		 * Result set of files.
		 */
		public static final String CONTENTS = "CONTENTS";

		/**
		 * Result set of document information.
		 */
		public static final String DOC_INFO = "DOC_INFO";
		/**
		 * Result set of document revision history.
		 */
		public static final String REVISION_HISTORY = "REVISION_HISTORY";
		/**
		 * Result set of revisions.
		 */
		public static final String REVISIONS = "REVISIONS";
	}

	/**
	 * Service names.
	 */
	public static final class Service {
		/**
		 * Private constructor.
		 */
		private Service() {
			// no-op
		}

		/**
		 * Gets document information.
		 */
		public static final String DOC_INFO = "DOC_INFO";

		/**
		 * Checks in a document revision.
		 */
		public static final String CHECKIN_REVISION = "CHECKIN_SEL";

		/**
		 * Calls the checkin form to get the revision label.
		 */
		public static final String CHECKIN_SEL_FORM = "CHECKIN_SEL_FORM";

		/**
		 * Checkin a file not in a folder.
		 */
		public static final String CHECKIN_UNIVERSAL = "CHECKIN_UNIVERSAL";
		/**
		 * Checks out a revision by revision id.
		 */
		public static final String CHECKOUT = "CHECKOUT";

		/**
		 * Checks out a document by content id.
		 */
		public static final String CHECKOUT_BY_NAME = "CHECKOUT_BY_NAME";
		/**
		 * Adds a folder.
		 */
		public static final String COLLECTION_ADD = "COLLECTION_ADD";
		/**
		 * Checks in a new document into a folder.
		 */
		public static final String COLLECTION_CHECKIN_NEW = "COLLECTION_CHECKIN_NEW";
		/**
		 * Gets folders and files in a folder.
		 */
		public static final String COLLECTION_BROWSE = "COLLECTION_BROWSE";
		/**
		 * Gets folders and files in a folder.
		 */
		public static final String COLLECTION_DISPLAY = "COLLECTION_DISPLAY";
		/**
		 * Enumerate first-level subfolders.
		 */
		public static final String COLLECTION_GET_COLLECTIONS = "COLLECTION_GET_COLLECTIONS";
		/**
		 * Enumerate first-level files in a folder.
		 */
		public static final String COLLECTION_GET_CONTENTS = "COLLECTION_GET_CONTENTS";

		/**
		 * Deletes a document version (revision).
		 */
		public static final String DELETE_REV = "DELETE_REV";

		/**
		 * Gets a File.
		 */
		public static final String GET_FILE = "GET_FILE";
		/**
		 * Ping the server to see that it is up.
		 */
		public static final String PING_SERVER = "PING_SERVER";
		/**
		 * Query the security group.
		 */
		public static final String QUERY_GROUP = "QUERY_GROUP";		
		/**
		 * Undoes checkout.
		 */
		public static final String UNDO_CHECKOUT = "UNDO_CHECKOUT";
		/**
		 * Revision history.
		 */
		public static final String REV_HISTORY = "REV_HISTORY";
	}

	/**
	 * Key to specify the service name.
	 */
	public static final String IDC_SERVICE = "IdcService";

	/**
	 * Private constructor for utility class.
	 */
	private UcmConstants() {
		// no-op
	}

}
