/*
 * Copyright (c) 2008 BEA Systems, Inc. All Rights Reserved.
 *
 * $Id: //Dev/ucmcrawler/main/src/com/oracle/wci/ucm/sci/ContainerTreeNode.java#3 $
 *
 * This software is the confidential and proprietary information of BEA Systems, Inc. ("Confidential
 * Information"). You shall not disclose such Confidential Information and shall use it only in accordance
 * with the terms of the license agreement you entered into with BEA Systems Inc.
 */

package com.oracle.wci.ucm.sci;

import java.util.LinkedList;
import java.util.List;

import com.plumtree.remote.sci.ITreeIteratorNode;

/**
 * UCM implementation of ITreeIteratorNode.
 * 
 * @author <a href="mailto:clinton.davidson@oracle.com">Clinton Davidson</a>
 * @version $Revision: #3 $ ($Change: 348620 $)
 */
public final class ContainerTreeNode implements ITreeIteratorNode {
	/**
	 * The name of the container.
	 */
	private String name;
	/**
	 * The image used for the container.
	 */
	private String img;
	/**
	 * The id of the container.
	 */
	private String loc;
	/**
	 * The children nodes of this node.
	 */
	private List children;
	/**
	 * The parent node of this node.
	 */
	private ContainerTreeNode parent;
	/**
	 * The default number of child locations of this node.
	 */
	private static final int DEFAULT_SIZE = 20;
	/**
	 * When the number of children equals the slots allocated for the children
	 * grow new slots by this number.
	 */
	private static final int GROWTH_FACTOR = 10;

	/**
	 * Constructor.
	 * 
	 * @param parent parent node
	 * @param name parent node name
	 * @param imageName image location
	 * @param location container id
	 */
	public ContainerTreeNode(ContainerTreeNode parent, String name, String imageName,
			String location) {
		super();
		this.name = name;
		this.img = imageName;
		this.loc = location;
		this.parent = parent;
		children = new LinkedList();
	}

	/**
	 * Inserts a node.
	 * @param node node to add to children
	 */
	public void insertNode(ContainerTreeNode node) {
		children.add(node);
	}

	/**
	 * Gets the subfolders for the current node.
	 * @return array of child containers
	 */
	public List getChildren() {
		return children;
	}

	/**
	 * Gets the parent node.
	 * @return the parent node
	 */
	public ContainerTreeNode getParent() {
		return parent;
	}

	/**
	 * Gets the display name of the node.
	 * @return ucm folder name
	 * @see com.plumtree.remote.sci.ITreeIteratorNode#getDisplayName()
	 */
	public String getDisplayName() {
		return name;
	}

	/**
	 * Gets the image name.
	 * @return path to open or closed folder on the image server
	 * @see com.plumtree.remote.sci.ITreeIteratorNode#getImageName()
	 */
	public String getImageName() {
		return img;
	}

	/**
	 * Gets the folder location.
	 * @return String which contains the folder name, a colon, and the folder id
	 * @see com.plumtree.remote.sci.ITreeIteratorNode#getLocation()
	 */
	public String getLocation() {
		return loc;
	}

}
