package com.oracle.wci.ucm.sci;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.oracle.wci.ucm.CrawlConstants;
import com.oracle.wci.ucm.Utilities;
import com.plumtree.remote.ServiceException;
import com.plumtree.remote.crawler.CrawlerConstants;
import com.plumtree.remote.sci.IAdminPage;
import com.plumtree.remote.util.NamedValue;
import com.plumtree.remote.util.NamedValueMap;

/**
 * Crawler Editor that returns a single page to choose the starting folder using a tree and select the crawl depth.
 * 
 * @author <a href="mailto:cdavidso@bea.com">Clinton Davidson</a>
 * @version $Revision: #3 $ ($Change: 348620 $)
 */
public final class CrawlerEditor extends AbstractEditor {

	/**
	 * Apache Commons Logger.
	 */
	private static final Log LOG = LogFactory.getLog(CrawlerEditor.class);

	/**
	 * Default constructor.
	 * 
	 * @param locale
	 *            string in the format "en-US", or just "en"
	 * @param parentInfo
	 *            data source settings
	 */
	public CrawlerEditor(String locale, NamedValueMap parentInfo) {
		super(locale, parentInfo);
	}

	/**
	 * Returns a page to select the starting folder and the crawl depth.
	 * 
	 * @return a page to choose the space type, and a page to select the space.
	 * @throws ServiceException
	 *             if an error occured when creating the IAdminPage.
	 * @see com.plumtree.remote.sci.IAdminEditor#getPages()
	 */
	@Override
	public  IAdminPage[] getPages() throws ServiceException {
		final IAdminPage[] pages = new IAdminPage[1];
		pages[0] = new FolderTreePage(this);
		return pages;
	}

	/**
	 * Sets the {@link com.plumtree.remote.crawler.CrawlerConstants#TAG_PATH}
	 * variable to the serialized properties of all the variables. This will be
	 * the initial value of containerLocation in
	 * {@link com.plumtree.remote.crawler.IContainerProvider#attachToContainer(String, com.plumtree.remote.crawler.ChildRequestHint, String)}.
	 * @param  pageInfo existing named values
	 * @return existing settings with the addition of
	 * 
	 * {@link CrawlerConstants#TAG_PATH}
	 * @throws ServiceException
	 *             never, as there are no Exceptions to catch
	 * @see com.plumtree.remote.sci.IAdminEditor#getPages()
	 */
	@Override
	public  NamedValue[] finalize(NamedValueMap pageInfo) throws ServiceException {
		if (LOG.isDebugEnabled()) {
			LOG.debug("CrawlerEditor.finalize(): pageInfo = " + pageInfo.toString());
		}
		// remove the existing PTC_UNIQUE if it exists
		pageInfo.remove(CrawlerConstants.TAG_PATH);

		// add a value for folder id
		final String folderAndId = pageInfo.get(CrawlConstants.Provider.ROOT_FOLDER_NAME_AND_ID);
		final int colonPos = folderAndId.indexOf(':');
		final String folderId = folderAndId.substring(colonPos + 1);
		pageInfo.put(CrawlConstants.Provider.START_FOLDER_ID, folderId);
		pageInfo.put(CrawlConstants.Provider.START_FOLDER_NAME, folderAndId.substring(0, colonPos));

		// serialize all the values to properties
		final Properties properties = new Properties();

		// we need to put the values into an array, as there is no iterator for
		// the named value map.
		final NamedValue[] namedValues = pageInfo.toArray();
		for (int i = 0; i < namedValues.length; i++) {
			final NamedValue namedValue = namedValues[i];

			properties.put(namedValue.getName(), namedValue.getValue());
		}
		// this is the value which be provided in the initial call for
		// attachToContainer
		final String tagPathValue = Utilities.propsToString(properties);
		pageInfo.put(CrawlerConstants.TAG_PATH, tagPathValue);

		return pageInfo.toArray();
	}
}
