package com.oracle.wci.ucm.sci;

import com.oracle.wci.ucm.CrawlConstants;
import com.plumtree.remote.ServiceException;
import com.plumtree.remote.sci.IAdminPage;
import com.plumtree.remote.util.NamedValue;
import com.plumtree.remote.util.NamedValueMap;

/**
 * Editor for datasource settings for crawler credentials and rdic server name and port.
 * 
 * @author <a href="mailto:cdavidso@bea.com">Clinton Davidson</a>
 * @version $Revision: #3 $ ($Change: 348620 $)
 */
public final class DatasourceEditor extends AbstractEditor {

	/**
	 * Default constructor.
	 * 
	 * @param locale
	 *            locale for localization.
	 * @param parentInfo
	 *            previously set named values.
	 */
	public DatasourceEditor(String locale, NamedValueMap parentInfo) {
		super(locale, parentInfo);
	}

	/**
	 * Gets the pages.
	 * @return the credentials page
	 * @throws ServiceException never
	 * @see com.plumtree.remote.sci.IAdminEditor#getPages()
	 */
	@Override
	public  IAdminPage[] getPages() throws ServiceException {
		final IAdminPage[] pages = new IAdminPage[1];
		pages[0] = new ConnectionInfoPage(this);
		return pages;
	}

	/**
	 * Constructs an idc url from the server and port, and adds it to the existing settings.
	 * @param pageInfo including values
	 * @return existing values from pageInfo, and an additional valud for CrawlConstants#Provider#IDC_URL
	 * @throws ServiceException never
	 * @see com.plumtree.remote.sci.IAdminEditor#finalize(NamedValueMap)
	 */
	@Override
	public  NamedValue[] finalize(NamedValueMap pageInfo)
	        throws ServiceException {
		final String server = pageInfo.get(CrawlConstants.Provider.UCM_SERVER);
		final String port = pageInfo.get(CrawlConstants.Provider.UCM_PORT);
		// construct the idc url
		final String idcUrl = "idc://" + server + ":" + port;
		pageInfo.put(CrawlConstants.Provider.IDC_URL, idcUrl);
		return pageInfo.toArray();
	}
}
