package com.oracle.wci.ucm.sci;



import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.plumtree.remote.ServiceException;
import com.plumtree.remote.crawler.ChildContainer;
/**
 * Container for child folders.
 * @author <a href="mailto:clinton.davidson@oracle.com">Clinton Davidson</a>
 * @version $Revision: #3 $ ($Change: 348620 $)
 */
public final class TreeContainer {
	
	/**
	 * Apache Commons Logger.
	 */
	private static final Log LOGGER = LogFactory.getLog(TreeContainer.class);
	/**
	 * The id of this container.
	 */
	private String id;
	/**
	 * Child containers found inside this container.
	 */
	private ChildContainer[] containers;
	/**
	 * The name of the container.
	 */
	private String name;
	/**
	 * Is this container the root container?
	 */
	private boolean isRoot;
	/**
	 * The parent id of this container.
	 */
	private String parentId;
	/**
	 * The full path of this container.
	 */
	private String path;
	
/**
 * Constructs a TreeContainer.
 * @param id parent id
 * @param containers subfolders of the current node
 * @param name container name
 * @param isRoot whether we are at the root
 * @param parentId parent id
 * @param path path to this container
 */
	public TreeContainer(String id, ChildContainer[] containers, String name, boolean isRoot, String parentId, String path)
	{
		super();
		
		LOGGER.debug("Entering constructor for:  TreeContainer");
		this.id = id;
		this.containers = containers;
		this.name = name;
		this.isRoot = isRoot;
		this.parentId = parentId;
		this.path = path;
		LOGGER.debug("Leaving constructor for:  TreeContainer");
	}
/**
 * Whether the tree container is at the root.
 * @return {@code true} if we are at the root.
 */
	public boolean isRoot() {
		return isRoot;
	}
/**
 * Sets whether we are at the root.
 * @param isRoot {@code true} if at the root
 */
	public void setRoot(boolean isRoot) {
		this.isRoot = isRoot;
	}
/**
 * Gets the parent id.
 * @return the parent id
 */
	public String getParentId() {
		return parentId;
	}
/**
 * Sets the parent id.
 * @param parentId parent id
 */
	public void setParentId(String parentId) {
		this.parentId = parentId;
	}
/**
 * Gets the path.
 * @return path
 */
	public String getPath() {
		return path;
	}
/**
 * Sets the path.
 * @param path path
 */
	public void setPath(String path) {
		this.path = path;
	}
/**
 * Gets the name.
 * @return name
 */
	public String getName() {
		return name;
	}
/**
 * Sets the name.
 * @param name name
 */
	public void setName(String name) {
		this.name = name;
	}
/**
 * Gets the child containers.
 * @return array of subfolders as child containers
 * @throws ServiceException never
 */
	public ChildContainer[] getChildContainers() throws ServiceException {
		return containers;
	}
	/**
	 * @return Returns the id.
	 */
	public String getId() {
		return id;
	}
	/**
	 * @param id The id to set.
	 */
	public void setId(String id) {
		this.id = id;
	}
}
