/*
 * Copyright (c) 2008 BEA Systems, Inc. All Rights Reserved.
 *
 * $Id: //Dev/ucmcrawler/main/src/com/oracle/wci/ucm/servlet/IndexServlet.java#3 $
 *
 * This software is the confidential and proprietary information of BEA Systems, Inc. ("Confidential
 * Information"). You shall not disclose such Confidential Information and shall use it only in accordance
 * with the terms of the license agreement you entered into with BEA Systems Inc.
 */

package com.oracle.wci.ucm.servlet;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.oracle.wci.ucm.CrawlConstants;
import com.oracle.wci.ucm.Utilities;

/**
 * Provides inline file binaries to the search service. The files are previously
 * written to the file system during the call to IDocument.getDocumentMetaData,
 * and the name of the file is added to the query string of the index url. Once
 * the file is read by the search service, the temp file is deleted.
 * 
 * @author <a href="mailto:clinton.davidson@oracle.com">Clinton Davidson</a>
 * @version $Revision: #3 $ ($Change: 348620 $)
 */
public final class IndexServlet extends HttpServlet {
	/**
	 * Serial version UID.
	 */
	private static final long serialVersionUID = -6157548361123940374L;
	/**
	 * Buffer size for sending bytes to the output stream.
	 */
	private static final int BUFFER_SIZE = 40 * 1024;

	/**
	 * Streams out the temp file specified in the query string, using the
	 * content type specified in the query string.
	 * 
	 * @param req
	 *            used to get query string params of file name and content type
	 * @param res
	 *            used to write file contents to the output stream
	 * @throws ServletException
	 *             if an unexpected error occurred
	 * @throws IOException
	 *             if unable to write file to servlet output stream
	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse)
	 */
	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
		// get the temp dir location
		final ServletContext servletContext = this.getServletContext();
		final File tempFileDir = Utilities.getTempDir(servletContext);
		// get the file name off the query string.
		final String tempFileName = req.getParameter(CrawlConstants.Misc.TEMP_FILENAME);
		final String contentType = req.getParameter(CrawlConstants.Misc.CONTENT_TYPE);
		final File file = new File(tempFileDir, tempFileName);
		FileInputStream inputStream = null;
		ServletOutputStream outputStream = null;
		// write to the output stream
		if (null != file && file.exists()) {
			res.setContentType(contentType);

			try {
				inputStream = new FileInputStream(file);
				// the filename should never have intl chars, so we don't have to
				// worry about encoding
				res.setHeader("Content-Disposition", "inline; filename=" + file.getName());
				res.setHeader("PTGW-Streaming", "Yes");
				outputStream = res.getOutputStream();
				final byte[] buf = new byte[BUFFER_SIZE];

				while (true) {
					final int bytesRead = inputStream.read(buf);
					if (bytesRead == -1) {
						break;
					}
					outputStream.write(buf, 0, bytesRead);
				}
			}
			catch (FileNotFoundException e) {
				e.printStackTrace();
			}
			catch (IOException e) {
				e.printStackTrace();
			} finally {
				// always close the streams and delete the underlying file
					if (null != inputStream) {
						inputStream.close();
					}
					if (null != outputStream) {
						outputStream.close();
					}
				file.delete();
			}
		}

	}

}
